alloc

Function alloc 

pub fn alloc(
    addr_space: &mut AddressSpace,
    fixed_addr: Option<VirtAddr>,
    size: u64,
    flags: VmaFlags,
) -> Result<VirtAddr, MmError>
Lazily allocate memory in the given user process’s address space

By passing the fixed_addr parameter, the caller can request the memory to be mapped into a specific location in the address space