free

Function free 

pub unsafe fn free(
    addr_space: &mut AddressSpace,
    virt: VirtAddr,
) -> Result<(), MmError>
Free previously by [alloc] allocated memory and release all associated frames back into the buddy allocator

Safety

The caller must ensure that no live code or data holds references into any address mapped within [virt, vma.end_addr) after this method call returns