remap_user_mem

Function remap_user_mem 

pub unsafe fn remap_user_mem(
    addr_space: &mut AddressSpace,
    virt: VirtAddr,
    new_flags: VmaFlags,
) -> Result<(), MmError>
Change an already mapped memory region’s access flags

Safety

The caller must ensure that for example when removing the WRITE flag, no mutable references to the to be modified memory is held.